/**
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License.
 */
import { Locator, WebDriver, Capabilities, WebElement, WebElementPromise, FileDetector, Session, Actions, WebElementCondition, Condition, Options, Navigation, TargetLocator } from 'selenium-webdriver';
import { Command, Executor } from 'selenium-webdriver/lib/command';
import { NetworkConnectionType } from './mobileextension';
interface INativeWaitAndGet {
    getByNativeAccessibilityId(id: string, timeout?: number, message?: string): WebElementPromise;
    getByNativeName(name: string, timeout?: number, message?: string): WebElementPromise;
    getByNativeId(id: string, timeout?: number, message?: string): WebElementPromise;
    getByNativeclassName(className: string, timeout?: number, message?: string): WebElementPromise;
}
interface IWaitAndGet extends INativeWaitAndGet {
    getBy(locator: Locator, timeout?: number, message?: string): WebElementPromise;
}
export interface IWebDriver2 extends IWaitAndGet {
    attach(webDriver: WebDriver): void;
    detach(): void;
    start(): Promise<void>;
    stop(): Promise<void>;
    restart(): Promise<void>;
    isActive(): Promise<boolean>;
    seleniumDriver(): WebDriver;
    lastError(): any;
}
export declare class WebDriver2 implements IWebDriver2 {
    /**
     * Schedules a command to get Chrome network emulation settings.
     * @return {!Promise} A promise that will be resolved when network
     *     emulation settings are retrievied.
     */
    getNetworkCondition(): Promise<{
        type: NetworkConnectionType;
    }>;
    setNetworkCondition(type: NetworkConnectionType): Promise<unknown>;
    wait(condition: WebElementCondition, opt_timeout?: number | undefined, opt_message?: string | undefined): WebElementPromise;
    wait2<T>(condition: Function | PromiseLike<T> | Condition<T> | ((driver: WebDriver) => T | PromiseLike<T>), opt_timeout?: number | undefined, opt_message?: string | undefined): Promise<T>;
    sleep(ms: number): Promise<void>;
    [Symbol.toStringTag]: string;
    execute<T>(command: Command, description?: string | undefined): Promise<T>;
    setFileDetector(detector: FileDetector): void;
    getExecutor(): Executor;
    getSession(): Promise<Session>;
    getCapabilities(): Promise<Capabilities>;
    quit(): Promise<void>;
    actions(options?: {
        async: boolean;
        bridge: boolean;
    } | {
        async: boolean;
    } | {
        bridge: boolean;
    } | undefined): Actions;
    executeScript<T>(script: string | Function, ...var_args: any[]): Promise<T>;
    executeAsyncScript<T>(script: string | Function, ...var_args: any[]): Promise<T>;
    getWindowHandle(): Promise<string>;
    getAllWindowHandles(): Promise<string[]>;
    getPageSource(): Promise<string>;
    close(): Promise<void>;
    get(url: string): Promise<void>;
    getCurrentUrl(): Promise<string>;
    getTitle(): Promise<string>;
    findElement(locator: Locator): WebElementPromise;
    findElements(locator: Locator): Promise<WebElement[]>;
    takeScreenshot(): Promise<string>;
    manage(): Options;
    navigate(): Navigation;
    switchTo(): TargetLocator;
    getBy(locator: Locator, timeout?: number, message?: string | undefined): WebElementPromise;
    getByNativeAccessibilityId(id: string, timeout?: number | undefined, message?: string | undefined): WebElementPromise;
    getByNativeName(name: string, timeout?: number | undefined, message?: string | undefined): WebElementPromise;
    getByNativeId(id: string, timeout?: number | undefined, message?: string | undefined): WebElementPromise;
    getByNativeclassName(className: string, timeout?: number | undefined, message?: string | undefined): WebElementPromise;
    seleniumDriver(): WebDriver;
    lastError(): any;
    attach(webDriver: WebDriver): void;
    detach(): void;
    start(): Promise<void>;
    stop(): Promise<void>;
    restart(): Promise<void>;
    private _restart;
    private capabilities_?;
    private error_?;
    private url_;
    private webDriver?;
    constructor(capabilities?: Capabilities | {}, url?: string);
    isActive(): Promise<boolean>;
}
export declare function createWebDriver2(capabilities?: Capabilities | {}, url?: string): WebDriver2;
export {};
